"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const rest_1 = require("../../rest");
const constants_1 = require("../../constants");
/**
 * Get resources on in CICS through CMCI REST API
 * @param {AbstractSession} session - the session to connect to CMCI with
 * @param {IResourceParms} parms - parameters for getting resources
 * @returns {Promise<ICMCIApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} CICS resource name not defined or blank
 * @throws {ImperativeError} CICS region name not defined or blank
 * @throws {ImperativeError} CicsCmciRestClient request fails
 */
function getResource(session, parms) {
    return __awaiter(this, void 0, void 0, function* () {
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.name, "CICS Resource name", "CICS resource name is required");
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.regionName, "CICS Region name", "CICS region name is required");
        let delimiter = "?"; // initial delimiter
        imperative_1.Logger.getAppLogger().debug("Attempting to get resource(s) with the following parameters:\n%s", JSON.stringify(parms));
        const cicsPlex = parms.cicsPlex == null ? "" : parms.cicsPlex + "/";
        let cmciResource = "/" + constants_1.CicsCmciConstants.CICS_SYSTEM_MANAGEMENT + "/" +
            parms.name + "/" + cicsPlex + parms.regionName;
        if (parms.criteria != null) {
            cmciResource = cmciResource + delimiter + "CRITERIA=(" + encodeURIComponent(parms.criteria) + ")";
            delimiter = "&";
        }
        if (parms.parameter != null) {
            cmciResource = cmciResource + delimiter + "PARAMETER=" + encodeURIComponent(parms.parameter);
        }
        return rest_1.CicsCmciRestClient.getExpectParsedXml(session, cmciResource, []);
    });
}
exports.getResource = getResource;
//# sourceMappingURL=Get.js.map