"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const __1 = require("../../../");
const util_1 = require("util");
/**
 * Command handler for calling a DB2 stored procedure
 * @export
 * @class ProcedureHandler
 * @implements {ICommandHandler}
 */
class ProcedureHandler {
    /**
     * Parse the passed values and create an array of OUTPUT parameters
     * @param {any[]} parameters Values of parameters
     * @returns {IDB2Parameter[]}
     */
    static parseParameters(parameters) {
        if (util_1.isNullOrUndefined(parameters)) {
            return [];
        }
        else {
            const parsed = parameters.map((value) => {
                const param = {
                    ParamType: __1.DB2_PARM_OUTPUT,
                    Data: value,
                };
                return param;
            });
            return parsed;
        }
    }
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const session = params.profiles.get("db2");
            const routine = params.arguments.routine;
            const parameters = ProcedureHandler.parseParameters(params.arguments.parameters);
            const response = __1.CallSP.callCommon(session, routine, parameters);
            // Print out the response
            params.response.console.log(imperative_1.TextUtils.prettyJson(response.results));
            // Return as an object when using --response-format-json
            params.response.data.setObj(response);
        });
    }
}
exports.default = ProcedureHandler;
//# sourceMappingURL=Procedure.handler.js.map