"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@brightside/imperative");
const upload_1 = require("../../../api/methods/upload");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
const path = require("path");
/**
 * Handler to upload content from a local directory to a USS directory
 * @export
 */
class DirToUSSDirHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let inputDir;
            // resolving to full path if passed path is not absolute
            if (path.isAbsolute(commandParameters.arguments.inputDir)) {
                inputDir = commandParameters.arguments.inputDir;
            }
            else {
                inputDir = path.resolve(commandParameters.arguments.inputDir);
            }
            // build filesMap argument
            let filesMap = null;
            // checking if binary-files or ascii-files are used, and update filesMap argument
            if (commandParameters.arguments.binaryFiles) {
                filesMap = {
                    binary: true,
                    fileNames: commandParameters.arguments.binaryFiles.split(",").map((fileName) => fileName.trim()),
                };
            }
            if (commandParameters.arguments.asciiFiles) {
                filesMap = {
                    binary: false,
                    fileNames: commandParameters.arguments.asciiFiles.split(",").map((fileName) => fileName.trim()),
                };
            }
            const response = yield upload_1.Upload.dirToUSSDir(session, inputDir, commandParameters.arguments.USSDir, commandParameters.arguments.binary, commandParameters.arguments.recursive, filesMap);
            const formatMessage = imperative_1.TextUtils.prettyJson(response.apiResponse);
            commandParameters.response.console.log(formatMessage);
            return response;
        });
    }
}
exports.default = DirToUSSDirHandler;
//# sourceMappingURL=DirToUSSDir.handler.js.map